@@ -28,13 +28,13 @@ for entity in ['users', 'groups', 'submissions', 'metadatasets', 'files', 'servi
     try:
         _prefix[entity] = threadlocal.get_current_registry().settings[f'datameta.site_id_prefix.{entity}']
     except Exception as e:
-        raise
-        log.warning(f"Site ID prefix for {entity} not found in configuration file ({e}).")
+        log.warning("Site ID prefix not found in configuration file", extra={"entity": entity, "error": e})
+        raise e
     try:
         _digits[entity] = int(threadlocal.get_current_registry().settings[f'datameta.site_id_digits.{entity}'])
     except Exception as e:
-        raise
-        log.warning(f"Site ID digits for {entity} not found in configuration file ({e}).")
+        log.warning("Site ID prefix not found in configuration file", extra={"entity": entity, "error": e})
+        raise e
 
 
 def generate(request, BaseClass):
@@ -44,6 +44,6 @@ def generate(request, BaseClass):
     for _ in range(10):
         new_id = prefix + str(random.randint(0, pow(10, digits))).rjust(digits, "0")
         if request.dbsession.query(BaseClass).filter(BaseClass.site_id == new_id).first():
-            log.warning(f"Site ID collision for {BaseClass.__tablename__}. Your ID space may be saturating.")
+            log.warning("Site ID collision, ID space may be saturating.", extra={"tablename": BaseClass.__tablename__})
         else:
             return new_id
